# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: BasicTypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Timestamp_pb2 as Timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='BasicTypes.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.hederahashgraph.api.proto.javaP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x42\x61sicTypes.proto\x12\x05proto\x1a\x0fTimestamp.proto\"\x1b\n\x07ShardID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\"-\n\x07RealmID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\"C\n\tAccountID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\x12\x12\n\naccountNum\x18\x03 \x01(\x03\"=\n\x06\x46ileID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\x12\x0f\n\x07\x66ileNum\x18\x03 \x01(\x03\"E\n\nContractID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontractNum\x18\x03 \x01(\x03\"x\n\rTransactionID\x12/\n\x15transactionValidStart\x18\x01 \x01(\x0b\x32\x10.proto.Timestamp\x12#\n\taccountID\x18\x02 \x01(\x0b\x32\x10.proto.AccountID\x12\x11\n\tscheduled\x18\x03 \x01(\x08\"D\n\rAccountAmount\x12#\n\taccountID\x18\x01 \x01(\x0b\x32\x10.proto.AccountID\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x12\"<\n\x0cTransferList\x12,\n\x0e\x61\x63\x63ountAmounts\x18\x01 \x03(\x0b\x32\x14.proto.AccountAmount\"{\n\x0bNftTransfer\x12)\n\x0fsenderAccountID\x18\x01 \x01(\x0b\x32\x10.proto.AccountID\x12+\n\x11receiverAccountID\x18\x02 \x01(\x0b\x32\x10.proto.AccountID\x12\x14\n\x0cserialNumber\x18\x03 \x01(\x03\"\x85\x01\n\x11TokenTransferList\x12\x1d\n\x05token\x18\x01 \x01(\x0b\x32\x0e.proto.TokenID\x12\'\n\ttransfers\x18\x02 \x03(\x0b\x32\x14.proto.AccountAmount\x12(\n\x0cnftTransfers\x18\x03 \x03(\x0b\x32\x12.proto.NftTransfer\"2\n\x08\x46raction\x12\x11\n\tnumerator\x18\x01 \x01(\x03\x12\x13\n\x0b\x64\x65nominator\x18\x02 \x01(\x03\"?\n\x07TopicID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\x12\x10\n\x08topicNum\x18\x03 \x01(\x03\"?\n\x07TokenID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\x12\x10\n\x08tokenNum\x18\x03 \x01(\x03\"E\n\nScheduleID\x12\x10\n\x08shardNum\x18\x01 \x01(\x03\x12\x10\n\x08realmNum\x18\x02 \x01(\x03\x12\x13\n\x0bscheduleNum\x18\x03 \x01(\x03\"\xc1\x01\n\x03Key\x12\'\n\ncontractID\x18\x01 \x01(\x0b\x32\x11.proto.ContractIDH\x00\x12\x11\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x02 \x01(\x0cH\x00\x12\x12\n\x08RSA_3072\x18\x03 \x01(\x0cH\x00\x12\x13\n\tECDSA_384\x18\x04 \x01(\x0cH\x00\x12+\n\x0cthresholdKey\x18\x05 \x01(\x0b\x32\x13.proto.ThresholdKeyH\x00\x12!\n\x07keyList\x18\x06 \x01(\x0b\x32\x0e.proto.KeyListH\x00\x42\x05\n\x03key\"?\n\x0cThresholdKey\x12\x11\n\tthreshold\x18\x01 \x01(\r\x12\x1c\n\x04keys\x18\x02 \x01(\x0b\x32\x0e.proto.KeyList\"#\n\x07KeyList\x12\x18\n\x04keys\x18\x01 \x03(\x0b\x32\n.proto.Key\"\xd4\x01\n\tSignature\x12\x12\n\x08\x63ontract\x18\x01 \x01(\x0cH\x00\x12\x11\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x02 \x01(\x0cH\x00\x12\x12\n\x08RSA_3072\x18\x03 \x01(\x0cH\x00\x12\x13\n\tECDSA_384\x18\x04 \x01(\x0cH\x00\x12\x37\n\x12thresholdSignature\x18\x05 \x01(\x0b\x32\x19.proto.ThresholdSignatureH\x00\x12-\n\rsignatureList\x18\x06 \x01(\x0b\x32\x14.proto.SignatureListH\x00:\x02\x18\x01\x42\x0b\n\tsignature\"<\n\x12ThresholdSignature\x12\"\n\x04sigs\x18\x02 \x01(\x0b\x32\x14.proto.SignatureList:\x02\x18\x01\"3\n\rSignatureList\x12\x1e\n\x04sigs\x18\x02 \x03(\x0b\x32\x10.proto.Signature:\x02\x18\x01\"\x82\x01\n\rSignaturePair\x12\x14\n\x0cpubKeyPrefix\x18\x01 \x01(\x0c\x12\x12\n\x08\x63ontract\x18\x02 \x01(\x0cH\x00\x12\x11\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x03 \x01(\x0cH\x00\x12\x12\n\x08RSA_3072\x18\x04 \x01(\x0cH\x00\x12\x13\n\tECDSA_384\x18\x05 \x01(\x0cH\x00\x42\x0b\n\tsignature\"5\n\x0cSignatureMap\x12%\n\x07sigPair\x18\x01 \x03(\x0b\x32\x14.proto.SignaturePair\"\xa3\x01\n\rFeeComponents\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x12\x10\n\x08\x63onstant\x18\x03 \x01(\x03\x12\x0b\n\x03\x62pt\x18\x04 \x01(\x03\x12\x0b\n\x03vpt\x18\x05 \x01(\x03\x12\x0b\n\x03rbh\x18\x06 \x01(\x03\x12\x0b\n\x03sbh\x18\x07 \x01(\x03\x12\x0b\n\x03gas\x18\x08 \x01(\x03\x12\n\n\x02tv\x18\t \x01(\x03\x12\x0b\n\x03\x62pr\x18\n \x01(\x03\x12\x0c\n\x04sbpr\x18\x0b \x01(\x03\"\x94\x01\n\x16TransactionFeeSchedule\x12\x37\n\x13hederaFunctionality\x18\x01 \x01(\x0e\x32\x1a.proto.HederaFunctionality\x12#\n\x07\x66\x65\x65\x44\x61ta\x18\x02 \x01(\x0b\x32\x0e.proto.FeeDataB\x02\x18\x01\x12\x1c\n\x04\x66\x65\x65s\x18\x03 \x03(\x0b\x32\x0e.proto.FeeData\"\xa8\x01\n\x07\x46\x65\x65\x44\x61ta\x12&\n\x08nodedata\x18\x01 \x01(\x0b\x32\x14.proto.FeeComponents\x12)\n\x0bnetworkdata\x18\x02 \x01(\x0b\x32\x14.proto.FeeComponents\x12)\n\x0bservicedata\x18\x03 \x01(\x0b\x32\x14.proto.FeeComponents\x12\x1f\n\x07subType\x18\x04 \x01(\x0e\x32\x0e.proto.SubType\"y\n\x0b\x46\x65\x65Schedule\x12=\n\x16transactionFeeSchedule\x18\x01 \x03(\x0b\x32\x1d.proto.TransactionFeeSchedule\x12+\n\nexpiryTime\x18\x02 \x01(\x0b\x32\x17.proto.TimestampSeconds\"x\n\x19\x43urrentAndNextFeeSchedule\x12.\n\x12\x63urrentFeeSchedule\x18\x01 \x01(\x0b\x32\x12.proto.FeeSchedule\x12+\n\x0fnextFeeSchedule\x18\x02 \x01(\x0b\x32\x12.proto.FeeSchedule\"4\n\x0fServiceEndpoint\x12\x13\n\x0bipAddressV4\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x82\x02\n\x0bNodeAddress\x12\x15\n\tipAddress\x18\x01 \x01(\x0c\x42\x02\x18\x01\x12\x12\n\x06portno\x18\x02 \x01(\x05\x42\x02\x18\x01\x12\x10\n\x04memo\x18\x03 \x01(\x0c\x42\x02\x18\x01\x12\x12\n\nRSA_PubKey\x18\x04 \x01(\t\x12\x0e\n\x06nodeId\x18\x05 \x01(\x03\x12\'\n\rnodeAccountId\x18\x06 \x01(\x0b\x32\x10.proto.AccountID\x12\x14\n\x0cnodeCertHash\x18\x07 \x01(\x0c\x12/\n\x0fserviceEndpoint\x18\x08 \x03(\x0b\x32\x16.proto.ServiceEndpoint\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\r\n\x05stake\x18\n \x01(\x03\":\n\x0fNodeAddressBook\x12\'\n\x0bnodeAddress\x18\x01 \x03(\x0b\x32\x12.proto.NodeAddress\"Z\n\x0fSemanticVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05\x12\x0b\n\x03pre\x18\x04 \x01(\t\x12\r\n\x05\x62uild\x18\x05 \x01(\t\"4\n\x07Setting\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\">\n\x19ServicesConfigurationList\x12!\n\tnameValue\x18\x01 \x03(\x0b\x32\x0e.proto.Setting\"\xc1\x01\n\x11TokenRelationship\x12\x1f\n\x07tokenId\x18\x01 \x01(\x0b\x32\x0e.proto.TokenID\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x03 \x01(\x04\x12(\n\tkycStatus\x18\x04 \x01(\x0e\x32\x15.proto.TokenKycStatus\x12.\n\x0c\x66reezeStatus\x18\x05 \x01(\x0e\x32\x18.proto.TokenFreezeStatus\x12\x10\n\x08\x64\x65\x63imals\x18\x06 \x01(\r\"R\n\x0cTokenBalance\x12\x1f\n\x07tokenId\x18\x01 \x01(\x0b\x32\x0e.proto.TokenID\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\x12\x10\n\x08\x64\x65\x63imals\x18\x03 \x01(\r\";\n\rTokenBalances\x12*\n\rtokenBalances\x18\x01 \x03(\x0b\x32\x13.proto.TokenBalance*9\n\tTokenType\x12\x13\n\x0f\x46UNGIBLE_COMMON\x10\x00\x12\x17\n\x13NON_FUNGIBLE_UNIQUE\x10\x01*\xac\x01\n\x07SubType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x19\n\x15TOKEN_FUNGIBLE_COMMON\x10\x01\x12\x1d\n\x19TOKEN_NON_FUNGIBLE_UNIQUE\x10\x02\x12*\n&TOKEN_FUNGIBLE_COMMON_WITH_CUSTOM_FEES\x10\x03\x12.\n*TOKEN_NON_FUNGIBLE_UNIQUE_WITH_CUSTOM_FEES\x10\x04*+\n\x0fTokenSupplyType\x12\x0c\n\x08INFINITE\x10\x00\x12\n\n\x06\x46INITE\x10\x01*F\n\x11TokenFreezeStatus\x12\x17\n\x13\x46reezeNotApplicable\x10\x00\x12\n\n\x06\x46rozen\x10\x01\x12\x0c\n\x08Unfrozen\x10\x02*@\n\x0eTokenKycStatus\x12\x14\n\x10KycNotApplicable\x10\x00\x12\x0b\n\x07Granted\x10\x01\x12\x0b\n\x07Revoked\x10\x02*\x83\x0b\n\x13HederaFunctionality\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0e\x43ryptoTransfer\x10\x01\x12\x10\n\x0c\x43ryptoUpdate\x10\x02\x12\x10\n\x0c\x43ryptoDelete\x10\x03\x12\x15\n\x11\x43ryptoAddLiveHash\x10\x04\x12\x18\n\x14\x43ryptoDeleteLiveHash\x10\x05\x12\x10\n\x0c\x43ontractCall\x10\x06\x12\x12\n\x0e\x43ontractCreate\x10\x07\x12\x12\n\x0e\x43ontractUpdate\x10\x08\x12\x0e\n\nFileCreate\x10\t\x12\x0e\n\nFileAppend\x10\n\x12\x0e\n\nFileUpdate\x10\x0b\x12\x0e\n\nFileDelete\x10\x0c\x12\x1b\n\x17\x43ryptoGetAccountBalance\x10\r\x12\x1b\n\x17\x43ryptoGetAccountRecords\x10\x0e\x12\x11\n\rCryptoGetInfo\x10\x0f\x12\x15\n\x11\x43ontractCallLocal\x10\x10\x12\x13\n\x0f\x43ontractGetInfo\x10\x11\x12\x17\n\x13\x43ontractGetBytecode\x10\x12\x12\x13\n\x0fGetBySolidityID\x10\x13\x12\x0c\n\x08GetByKey\x10\x14\x12\x15\n\x11\x43ryptoGetLiveHash\x10\x15\x12\x14\n\x10\x43ryptoGetStakers\x10\x16\x12\x13\n\x0f\x46ileGetContents\x10\x17\x12\x0f\n\x0b\x46ileGetInfo\x10\x18\x12\x18\n\x14TransactionGetRecord\x10\x19\x12\x16\n\x12\x43ontractGetRecords\x10\x1a\x12\x10\n\x0c\x43ryptoCreate\x10\x1b\x12\x10\n\x0cSystemDelete\x10\x1c\x12\x12\n\x0eSystemUndelete\x10\x1d\x12\x12\n\x0e\x43ontractDelete\x10\x1e\x12\n\n\x06\x46reeze\x10\x1f\x12\x1b\n\x17\x43reateTransactionRecord\x10 \x12\x1a\n\x16\x43ryptoAccountAutoRenew\x10!\x12\x15\n\x11\x43ontractAutoRenew\x10\"\x12\x12\n\x0eGetVersionInfo\x10#\x12\x19\n\x15TransactionGetReceipt\x10$\x12\x18\n\x14\x43onsensusCreateTopic\x10\x32\x12\x18\n\x14\x43onsensusUpdateTopic\x10\x33\x12\x18\n\x14\x43onsensusDeleteTopic\x10\x34\x12\x19\n\x15\x43onsensusGetTopicInfo\x10\x35\x12\x1a\n\x16\x43onsensusSubmitMessage\x10\x36\x12\x13\n\x0fUncheckedSubmit\x10\x37\x12\x0f\n\x0bTokenCreate\x10\x38\x12\x10\n\x0cTokenGetInfo\x10:\x12\x16\n\x12TokenFreezeAccount\x10;\x12\x18\n\x14TokenUnfreezeAccount\x10<\x12\x1a\n\x16TokenGrantKycToAccount\x10=\x12\x1d\n\x19TokenRevokeKycFromAccount\x10>\x12\x0f\n\x0bTokenDelete\x10?\x12\x0f\n\x0bTokenUpdate\x10@\x12\r\n\tTokenMint\x10\x41\x12\r\n\tTokenBurn\x10\x42\x12\x14\n\x10TokenAccountWipe\x10\x43\x12\x1b\n\x17TokenAssociateToAccount\x10\x44\x12\x1e\n\x1aTokenDissociateFromAccount\x10\x45\x12\x12\n\x0eScheduleCreate\x10\x46\x12\x12\n\x0eScheduleDelete\x10G\x12\x10\n\x0cScheduleSign\x10H\x12\x13\n\x0fScheduleGetInfo\x10I\x12\x1b\n\x17TokenGetAccountNftInfos\x10J\x12\x13\n\x0fTokenGetNftInfo\x10K\x12\x14\n\x10TokenGetNftInfos\x10L\x12\x1a\n\x16TokenFeeScheduleUpdate\x10MB&\n\"com.hederahashgraph.api.proto.javaP\x01\x62\x06proto3'
  ,
  dependencies=[Timestamp__pb2.DESCRIPTOR,])

_TOKENTYPE = _descriptor.EnumDescriptor(
  name='TokenType',
  full_name='proto.TokenType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FUNGIBLE_COMMON', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NON_FUNGIBLE_UNIQUE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3566,
  serialized_end=3623,
)
_sym_db.RegisterEnumDescriptor(_TOKENTYPE)

TokenType = enum_type_wrapper.EnumTypeWrapper(_TOKENTYPE)
_SUBTYPE = _descriptor.EnumDescriptor(
  name='SubType',
  full_name='proto.SubType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKEN_FUNGIBLE_COMMON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKEN_NON_FUNGIBLE_UNIQUE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKEN_FUNGIBLE_COMMON_WITH_CUSTOM_FEES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKEN_NON_FUNGIBLE_UNIQUE_WITH_CUSTOM_FEES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3626,
  serialized_end=3798,
)
_sym_db.RegisterEnumDescriptor(_SUBTYPE)

SubType = enum_type_wrapper.EnumTypeWrapper(_SUBTYPE)
_TOKENSUPPLYTYPE = _descriptor.EnumDescriptor(
  name='TokenSupplyType',
  full_name='proto.TokenSupplyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INFINITE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINITE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3800,
  serialized_end=3843,
)
_sym_db.RegisterEnumDescriptor(_TOKENSUPPLYTYPE)

TokenSupplyType = enum_type_wrapper.EnumTypeWrapper(_TOKENSUPPLYTYPE)
_TOKENFREEZESTATUS = _descriptor.EnumDescriptor(
  name='TokenFreezeStatus',
  full_name='proto.TokenFreezeStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FreezeNotApplicable', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Frozen', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Unfrozen', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3845,
  serialized_end=3915,
)
_sym_db.RegisterEnumDescriptor(_TOKENFREEZESTATUS)

TokenFreezeStatus = enum_type_wrapper.EnumTypeWrapper(_TOKENFREEZESTATUS)
_TOKENKYCSTATUS = _descriptor.EnumDescriptor(
  name='TokenKycStatus',
  full_name='proto.TokenKycStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KycNotApplicable', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Granted', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Revoked', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3917,
  serialized_end=3981,
)
_sym_db.RegisterEnumDescriptor(_TOKENKYCSTATUS)

TokenKycStatus = enum_type_wrapper.EnumTypeWrapper(_TOKENKYCSTATUS)
_HEDERAFUNCTIONALITY = _descriptor.EnumDescriptor(
  name='HederaFunctionality',
  full_name='proto.HederaFunctionality',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoTransfer', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoUpdate', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoDelete', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoAddLiveHash', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoDeleteLiveHash', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractCall', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractCreate', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractUpdate', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FileCreate', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FileAppend', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FileUpdate', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FileDelete', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoGetAccountBalance', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoGetAccountRecords', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoGetInfo', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractCallLocal', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractGetInfo', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractGetBytecode', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GetBySolidityID', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GetByKey', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoGetLiveHash', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoGetStakers', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FileGetContents', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FileGetInfo', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TransactionGetRecord', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractGetRecords', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoCreate', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SystemDelete', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SystemUndelete', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractDelete', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Freeze', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CreateTransactionRecord', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CryptoAccountAutoRenew', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ContractAutoRenew', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GetVersionInfo', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TransactionGetReceipt', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConsensusCreateTopic', index=37, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConsensusUpdateTopic', index=38, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConsensusDeleteTopic', index=39, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConsensusGetTopicInfo', index=40, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConsensusSubmitMessage', index=41, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UncheckedSubmit', index=42, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenCreate', index=43, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenGetInfo', index=44, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenFreezeAccount', index=45, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenUnfreezeAccount', index=46, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenGrantKycToAccount', index=47, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenRevokeKycFromAccount', index=48, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenDelete', index=49, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenUpdate', index=50, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenMint', index=51, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenBurn', index=52, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenAccountWipe', index=53, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenAssociateToAccount', index=54, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenDissociateFromAccount', index=55, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ScheduleCreate', index=56, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ScheduleDelete', index=57, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ScheduleSign', index=58, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ScheduleGetInfo', index=59, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenGetAccountNftInfos', index=60, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenGetNftInfo', index=61, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenGetNftInfos', index=62, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TokenFeeScheduleUpdate', index=63, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3984,
  serialized_end=5395,
)
_sym_db.RegisterEnumDescriptor(_HEDERAFUNCTIONALITY)

HederaFunctionality = enum_type_wrapper.EnumTypeWrapper(_HEDERAFUNCTIONALITY)
FUNGIBLE_COMMON = 0
NON_FUNGIBLE_UNIQUE = 1
DEFAULT = 0
TOKEN_FUNGIBLE_COMMON = 1
TOKEN_NON_FUNGIBLE_UNIQUE = 2
TOKEN_FUNGIBLE_COMMON_WITH_CUSTOM_FEES = 3
TOKEN_NON_FUNGIBLE_UNIQUE_WITH_CUSTOM_FEES = 4
INFINITE = 0
FINITE = 1
FreezeNotApplicable = 0
Frozen = 1
Unfrozen = 2
KycNotApplicable = 0
Granted = 1
Revoked = 2
NONE = 0
CryptoTransfer = 1
CryptoUpdate = 2
CryptoDelete = 3
CryptoAddLiveHash = 4
CryptoDeleteLiveHash = 5
ContractCall = 6
ContractCreate = 7
ContractUpdate = 8
FileCreate = 9
FileAppend = 10
FileUpdate = 11
FileDelete = 12
CryptoGetAccountBalance = 13
CryptoGetAccountRecords = 14
CryptoGetInfo = 15
ContractCallLocal = 16
ContractGetInfo = 17
ContractGetBytecode = 18
GetBySolidityID = 19
GetByKey = 20
CryptoGetLiveHash = 21
CryptoGetStakers = 22
FileGetContents = 23
FileGetInfo = 24
TransactionGetRecord = 25
ContractGetRecords = 26
CryptoCreate = 27
SystemDelete = 28
SystemUndelete = 29
ContractDelete = 30
Freeze = 31
CreateTransactionRecord = 32
CryptoAccountAutoRenew = 33
ContractAutoRenew = 34
GetVersionInfo = 35
TransactionGetReceipt = 36
ConsensusCreateTopic = 50
ConsensusUpdateTopic = 51
ConsensusDeleteTopic = 52
ConsensusGetTopicInfo = 53
ConsensusSubmitMessage = 54
UncheckedSubmit = 55
TokenCreate = 56
TokenGetInfo = 58
TokenFreezeAccount = 59
TokenUnfreezeAccount = 60
TokenGrantKycToAccount = 61
TokenRevokeKycFromAccount = 62
TokenDelete = 63
TokenUpdate = 64
TokenMint = 65
TokenBurn = 66
TokenAccountWipe = 67
TokenAssociateToAccount = 68
TokenDissociateFromAccount = 69
ScheduleCreate = 70
ScheduleDelete = 71
ScheduleSign = 72
ScheduleGetInfo = 73
TokenGetAccountNftInfos = 74
TokenGetNftInfo = 75
TokenGetNftInfos = 76
TokenFeeScheduleUpdate = 77



_SHARDID = _descriptor.Descriptor(
  name='ShardID',
  full_name='proto.ShardID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.ShardID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=71,
)


_REALMID = _descriptor.Descriptor(
  name='RealmID',
  full_name='proto.RealmID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.RealmID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.RealmID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=118,
)


_ACCOUNTID = _descriptor.Descriptor(
  name='AccountID',
  full_name='proto.AccountID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.AccountID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.AccountID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountNum', full_name='proto.AccountID.accountNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=187,
)


_FILEID = _descriptor.Descriptor(
  name='FileID',
  full_name='proto.FileID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.FileID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.FileID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fileNum', full_name='proto.FileID.fileNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=250,
)


_CONTRACTID = _descriptor.Descriptor(
  name='ContractID',
  full_name='proto.ContractID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.ContractID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.ContractID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractNum', full_name='proto.ContractID.contractNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=321,
)


_TRANSACTIONID = _descriptor.Descriptor(
  name='TransactionID',
  full_name='proto.TransactionID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionValidStart', full_name='proto.TransactionID.transactionValidStart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountID', full_name='proto.TransactionID.accountID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduled', full_name='proto.TransactionID.scheduled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=443,
)


_ACCOUNTAMOUNT = _descriptor.Descriptor(
  name='AccountAmount',
  full_name='proto.AccountAmount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountID', full_name='proto.AccountAmount.accountID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.AccountAmount.amount', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=513,
)


_TRANSFERLIST = _descriptor.Descriptor(
  name='TransferList',
  full_name='proto.TransferList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountAmounts', full_name='proto.TransferList.accountAmounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=575,
)


_NFTTRANSFER = _descriptor.Descriptor(
  name='NftTransfer',
  full_name='proto.NftTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='senderAccountID', full_name='proto.NftTransfer.senderAccountID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiverAccountID', full_name='proto.NftTransfer.receiverAccountID', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialNumber', full_name='proto.NftTransfer.serialNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=700,
)


_TOKENTRANSFERLIST = _descriptor.Descriptor(
  name='TokenTransferList',
  full_name='proto.TokenTransferList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.TokenTransferList.token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfers', full_name='proto.TokenTransferList.transfers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nftTransfers', full_name='proto.TokenTransferList.nftTransfers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=836,
)


_FRACTION = _descriptor.Descriptor(
  name='Fraction',
  full_name='proto.Fraction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='numerator', full_name='proto.Fraction.numerator', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denominator', full_name='proto.Fraction.denominator', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=888,
)


_TOPICID = _descriptor.Descriptor(
  name='TopicID',
  full_name='proto.TopicID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.TopicID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.TopicID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topicNum', full_name='proto.TopicID.topicNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=953,
)


_TOKENID = _descriptor.Descriptor(
  name='TokenID',
  full_name='proto.TokenID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.TokenID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.TokenID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tokenNum', full_name='proto.TokenID.tokenNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=955,
  serialized_end=1018,
)


_SCHEDULEID = _descriptor.Descriptor(
  name='ScheduleID',
  full_name='proto.ScheduleID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shardNum', full_name='proto.ScheduleID.shardNum', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realmNum', full_name='proto.ScheduleID.realmNum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduleNum', full_name='proto.ScheduleID.scheduleNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1089,
)


_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='proto.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contractID', full_name='proto.Key.contractID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ed25519', full_name='proto.Key.ed25519', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RSA_3072', full_name='proto.Key.RSA_3072', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ECDSA_384', full_name='proto.Key.ECDSA_384', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thresholdKey', full_name='proto.Key.thresholdKey', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyList', full_name='proto.Key.keyList', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key', full_name='proto.Key.key',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1092,
  serialized_end=1285,
)


_THRESHOLDKEY = _descriptor.Descriptor(
  name='ThresholdKey',
  full_name='proto.ThresholdKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='proto.ThresholdKey.threshold', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keys', full_name='proto.ThresholdKey.keys', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1287,
  serialized_end=1350,
)


_KEYLIST = _descriptor.Descriptor(
  name='KeyList',
  full_name='proto.KeyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='proto.KeyList.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1352,
  serialized_end=1387,
)


_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='proto.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract', full_name='proto.Signature.contract', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ed25519', full_name='proto.Signature.ed25519', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RSA_3072', full_name='proto.Signature.RSA_3072', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ECDSA_384', full_name='proto.Signature.ECDSA_384', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thresholdSignature', full_name='proto.Signature.thresholdSignature', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatureList', full_name='proto.Signature.signatureList', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='signature', full_name='proto.Signature.signature',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1390,
  serialized_end=1602,
)


_THRESHOLDSIGNATURE = _descriptor.Descriptor(
  name='ThresholdSignature',
  full_name='proto.ThresholdSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sigs', full_name='proto.ThresholdSignature.sigs', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1604,
  serialized_end=1664,
)


_SIGNATURELIST = _descriptor.Descriptor(
  name='SignatureList',
  full_name='proto.SignatureList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sigs', full_name='proto.SignatureList.sigs', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1717,
)


_SIGNATUREPAIR = _descriptor.Descriptor(
  name='SignaturePair',
  full_name='proto.SignaturePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubKeyPrefix', full_name='proto.SignaturePair.pubKeyPrefix', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='proto.SignaturePair.contract', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ed25519', full_name='proto.SignaturePair.ed25519', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RSA_3072', full_name='proto.SignaturePair.RSA_3072', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ECDSA_384', full_name='proto.SignaturePair.ECDSA_384', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='signature', full_name='proto.SignaturePair.signature',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1720,
  serialized_end=1850,
)


_SIGNATUREMAP = _descriptor.Descriptor(
  name='SignatureMap',
  full_name='proto.SignatureMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sigPair', full_name='proto.SignatureMap.sigPair', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1905,
)


_FEECOMPONENTS = _descriptor.Descriptor(
  name='FeeComponents',
  full_name='proto.FeeComponents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='proto.FeeComponents.min', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='proto.FeeComponents.max', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constant', full_name='proto.FeeComponents.constant', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bpt', full_name='proto.FeeComponents.bpt', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vpt', full_name='proto.FeeComponents.vpt', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rbh', full_name='proto.FeeComponents.rbh', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sbh', full_name='proto.FeeComponents.sbh', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas', full_name='proto.FeeComponents.gas', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tv', full_name='proto.FeeComponents.tv', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bpr', full_name='proto.FeeComponents.bpr', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sbpr', full_name='proto.FeeComponents.sbpr', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1908,
  serialized_end=2071,
)


_TRANSACTIONFEESCHEDULE = _descriptor.Descriptor(
  name='TransactionFeeSchedule',
  full_name='proto.TransactionFeeSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hederaFunctionality', full_name='proto.TransactionFeeSchedule.hederaFunctionality', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feeData', full_name='proto.TransactionFeeSchedule.feeData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fees', full_name='proto.TransactionFeeSchedule.fees', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2074,
  serialized_end=2222,
)


_FEEDATA = _descriptor.Descriptor(
  name='FeeData',
  full_name='proto.FeeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodedata', full_name='proto.FeeData.nodedata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='networkdata', full_name='proto.FeeData.networkdata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='servicedata', full_name='proto.FeeData.servicedata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subType', full_name='proto.FeeData.subType', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2225,
  serialized_end=2393,
)


_FEESCHEDULE = _descriptor.Descriptor(
  name='FeeSchedule',
  full_name='proto.FeeSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionFeeSchedule', full_name='proto.FeeSchedule.transactionFeeSchedule', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiryTime', full_name='proto.FeeSchedule.expiryTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2395,
  serialized_end=2516,
)


_CURRENTANDNEXTFEESCHEDULE = _descriptor.Descriptor(
  name='CurrentAndNextFeeSchedule',
  full_name='proto.CurrentAndNextFeeSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentFeeSchedule', full_name='proto.CurrentAndNextFeeSchedule.currentFeeSchedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nextFeeSchedule', full_name='proto.CurrentAndNextFeeSchedule.nextFeeSchedule', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2638,
)


_SERVICEENDPOINT = _descriptor.Descriptor(
  name='ServiceEndpoint',
  full_name='proto.ServiceEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipAddressV4', full_name='proto.ServiceEndpoint.ipAddressV4', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='proto.ServiceEndpoint.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2640,
  serialized_end=2692,
)


_NODEADDRESS = _descriptor.Descriptor(
  name='NodeAddress',
  full_name='proto.NodeAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipAddress', full_name='proto.NodeAddress.ipAddress', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portno', full_name='proto.NodeAddress.portno', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memo', full_name='proto.NodeAddress.memo', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RSA_PubKey', full_name='proto.NodeAddress.RSA_PubKey', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='proto.NodeAddress.nodeId', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeAccountId', full_name='proto.NodeAddress.nodeAccountId', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeCertHash', full_name='proto.NodeAddress.nodeCertHash', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceEndpoint', full_name='proto.NodeAddress.serviceEndpoint', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='proto.NodeAddress.description', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stake', full_name='proto.NodeAddress.stake', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2695,
  serialized_end=2953,
)


_NODEADDRESSBOOK = _descriptor.Descriptor(
  name='NodeAddressBook',
  full_name='proto.NodeAddressBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeAddress', full_name='proto.NodeAddressBook.nodeAddress', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2955,
  serialized_end=3013,
)


_SEMANTICVERSION = _descriptor.Descriptor(
  name='SemanticVersion',
  full_name='proto.SemanticVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='proto.SemanticVersion.major', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='proto.SemanticVersion.minor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch', full_name='proto.SemanticVersion.patch', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre', full_name='proto.SemanticVersion.pre', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build', full_name='proto.SemanticVersion.build', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3015,
  serialized_end=3105,
)


_SETTING = _descriptor.Descriptor(
  name='Setting',
  full_name='proto.Setting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.Setting.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.Setting.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='proto.Setting.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3107,
  serialized_end=3159,
)


_SERVICESCONFIGURATIONLIST = _descriptor.Descriptor(
  name='ServicesConfigurationList',
  full_name='proto.ServicesConfigurationList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nameValue', full_name='proto.ServicesConfigurationList.nameValue', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3161,
  serialized_end=3223,
)


_TOKENRELATIONSHIP = _descriptor.Descriptor(
  name='TokenRelationship',
  full_name='proto.TokenRelationship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokenId', full_name='proto.TokenRelationship.tokenId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='proto.TokenRelationship.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='proto.TokenRelationship.balance', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kycStatus', full_name='proto.TokenRelationship.kycStatus', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freezeStatus', full_name='proto.TokenRelationship.freezeStatus', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='proto.TokenRelationship.decimals', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3226,
  serialized_end=3419,
)


_TOKENBALANCE = _descriptor.Descriptor(
  name='TokenBalance',
  full_name='proto.TokenBalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokenId', full_name='proto.TokenBalance.tokenId', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='proto.TokenBalance.balance', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='proto.TokenBalance.decimals', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3421,
  serialized_end=3503,
)


_TOKENBALANCES = _descriptor.Descriptor(
  name='TokenBalances',
  full_name='proto.TokenBalances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokenBalances', full_name='proto.TokenBalances.tokenBalances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3505,
  serialized_end=3564,
)

_TRANSACTIONID.fields_by_name['transactionValidStart'].message_type = Timestamp__pb2._TIMESTAMP
_TRANSACTIONID.fields_by_name['accountID'].message_type = _ACCOUNTID
_ACCOUNTAMOUNT.fields_by_name['accountID'].message_type = _ACCOUNTID
_TRANSFERLIST.fields_by_name['accountAmounts'].message_type = _ACCOUNTAMOUNT
_NFTTRANSFER.fields_by_name['senderAccountID'].message_type = _ACCOUNTID
_NFTTRANSFER.fields_by_name['receiverAccountID'].message_type = _ACCOUNTID
_TOKENTRANSFERLIST.fields_by_name['token'].message_type = _TOKENID
_TOKENTRANSFERLIST.fields_by_name['transfers'].message_type = _ACCOUNTAMOUNT
_TOKENTRANSFERLIST.fields_by_name['nftTransfers'].message_type = _NFTTRANSFER
_KEY.fields_by_name['contractID'].message_type = _CONTRACTID
_KEY.fields_by_name['thresholdKey'].message_type = _THRESHOLDKEY
_KEY.fields_by_name['keyList'].message_type = _KEYLIST
_KEY.oneofs_by_name['key'].fields.append(
  _KEY.fields_by_name['contractID'])
_KEY.fields_by_name['contractID'].containing_oneof = _KEY.oneofs_by_name['key']
_KEY.oneofs_by_name['key'].fields.append(
  _KEY.fields_by_name['ed25519'])
_KEY.fields_by_name['ed25519'].containing_oneof = _KEY.oneofs_by_name['key']
_KEY.oneofs_by_name['key'].fields.append(
  _KEY.fields_by_name['RSA_3072'])
_KEY.fields_by_name['RSA_3072'].containing_oneof = _KEY.oneofs_by_name['key']
_KEY.oneofs_by_name['key'].fields.append(
  _KEY.fields_by_name['ECDSA_384'])
_KEY.fields_by_name['ECDSA_384'].containing_oneof = _KEY.oneofs_by_name['key']
_KEY.oneofs_by_name['key'].fields.append(
  _KEY.fields_by_name['thresholdKey'])
_KEY.fields_by_name['thresholdKey'].containing_oneof = _KEY.oneofs_by_name['key']
_KEY.oneofs_by_name['key'].fields.append(
  _KEY.fields_by_name['keyList'])
_KEY.fields_by_name['keyList'].containing_oneof = _KEY.oneofs_by_name['key']
_THRESHOLDKEY.fields_by_name['keys'].message_type = _KEYLIST
_KEYLIST.fields_by_name['keys'].message_type = _KEY
_SIGNATURE.fields_by_name['thresholdSignature'].message_type = _THRESHOLDSIGNATURE
_SIGNATURE.fields_by_name['signatureList'].message_type = _SIGNATURELIST
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['contract'])
_SIGNATURE.fields_by_name['contract'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['ed25519'])
_SIGNATURE.fields_by_name['ed25519'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['RSA_3072'])
_SIGNATURE.fields_by_name['RSA_3072'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['ECDSA_384'])
_SIGNATURE.fields_by_name['ECDSA_384'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['thresholdSignature'])
_SIGNATURE.fields_by_name['thresholdSignature'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['signatureList'])
_SIGNATURE.fields_by_name['signatureList'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_THRESHOLDSIGNATURE.fields_by_name['sigs'].message_type = _SIGNATURELIST
_SIGNATURELIST.fields_by_name['sigs'].message_type = _SIGNATURE
_SIGNATUREPAIR.oneofs_by_name['signature'].fields.append(
  _SIGNATUREPAIR.fields_by_name['contract'])
_SIGNATUREPAIR.fields_by_name['contract'].containing_oneof = _SIGNATUREPAIR.oneofs_by_name['signature']
_SIGNATUREPAIR.oneofs_by_name['signature'].fields.append(
  _SIGNATUREPAIR.fields_by_name['ed25519'])
_SIGNATUREPAIR.fields_by_name['ed25519'].containing_oneof = _SIGNATUREPAIR.oneofs_by_name['signature']
_SIGNATUREPAIR.oneofs_by_name['signature'].fields.append(
  _SIGNATUREPAIR.fields_by_name['RSA_3072'])
_SIGNATUREPAIR.fields_by_name['RSA_3072'].containing_oneof = _SIGNATUREPAIR.oneofs_by_name['signature']
_SIGNATUREPAIR.oneofs_by_name['signature'].fields.append(
  _SIGNATUREPAIR.fields_by_name['ECDSA_384'])
_SIGNATUREPAIR.fields_by_name['ECDSA_384'].containing_oneof = _SIGNATUREPAIR.oneofs_by_name['signature']
_SIGNATUREMAP.fields_by_name['sigPair'].message_type = _SIGNATUREPAIR
_TRANSACTIONFEESCHEDULE.fields_by_name['hederaFunctionality'].enum_type = _HEDERAFUNCTIONALITY
_TRANSACTIONFEESCHEDULE.fields_by_name['feeData'].message_type = _FEEDATA
_TRANSACTIONFEESCHEDULE.fields_by_name['fees'].message_type = _FEEDATA
_FEEDATA.fields_by_name['nodedata'].message_type = _FEECOMPONENTS
_FEEDATA.fields_by_name['networkdata'].message_type = _FEECOMPONENTS
_FEEDATA.fields_by_name['servicedata'].message_type = _FEECOMPONENTS
_FEEDATA.fields_by_name['subType'].enum_type = _SUBTYPE
_FEESCHEDULE.fields_by_name['transactionFeeSchedule'].message_type = _TRANSACTIONFEESCHEDULE
_FEESCHEDULE.fields_by_name['expiryTime'].message_type = Timestamp__pb2._TIMESTAMPSECONDS
_CURRENTANDNEXTFEESCHEDULE.fields_by_name['currentFeeSchedule'].message_type = _FEESCHEDULE
_CURRENTANDNEXTFEESCHEDULE.fields_by_name['nextFeeSchedule'].message_type = _FEESCHEDULE
_NODEADDRESS.fields_by_name['nodeAccountId'].message_type = _ACCOUNTID
_NODEADDRESS.fields_by_name['serviceEndpoint'].message_type = _SERVICEENDPOINT
_NODEADDRESSBOOK.fields_by_name['nodeAddress'].message_type = _NODEADDRESS
_SERVICESCONFIGURATIONLIST.fields_by_name['nameValue'].message_type = _SETTING
_TOKENRELATIONSHIP.fields_by_name['tokenId'].message_type = _TOKENID
_TOKENRELATIONSHIP.fields_by_name['kycStatus'].enum_type = _TOKENKYCSTATUS
_TOKENRELATIONSHIP.fields_by_name['freezeStatus'].enum_type = _TOKENFREEZESTATUS
_TOKENBALANCE.fields_by_name['tokenId'].message_type = _TOKENID
_TOKENBALANCES.fields_by_name['tokenBalances'].message_type = _TOKENBALANCE
DESCRIPTOR.message_types_by_name['ShardID'] = _SHARDID
DESCRIPTOR.message_types_by_name['RealmID'] = _REALMID
DESCRIPTOR.message_types_by_name['AccountID'] = _ACCOUNTID
DESCRIPTOR.message_types_by_name['FileID'] = _FILEID
DESCRIPTOR.message_types_by_name['ContractID'] = _CONTRACTID
DESCRIPTOR.message_types_by_name['TransactionID'] = _TRANSACTIONID
DESCRIPTOR.message_types_by_name['AccountAmount'] = _ACCOUNTAMOUNT
DESCRIPTOR.message_types_by_name['TransferList'] = _TRANSFERLIST
DESCRIPTOR.message_types_by_name['NftTransfer'] = _NFTTRANSFER
DESCRIPTOR.message_types_by_name['TokenTransferList'] = _TOKENTRANSFERLIST
DESCRIPTOR.message_types_by_name['Fraction'] = _FRACTION
DESCRIPTOR.message_types_by_name['TopicID'] = _TOPICID
DESCRIPTOR.message_types_by_name['TokenID'] = _TOKENID
DESCRIPTOR.message_types_by_name['ScheduleID'] = _SCHEDULEID
DESCRIPTOR.message_types_by_name['Key'] = _KEY
DESCRIPTOR.message_types_by_name['ThresholdKey'] = _THRESHOLDKEY
DESCRIPTOR.message_types_by_name['KeyList'] = _KEYLIST
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
DESCRIPTOR.message_types_by_name['ThresholdSignature'] = _THRESHOLDSIGNATURE
DESCRIPTOR.message_types_by_name['SignatureList'] = _SIGNATURELIST
DESCRIPTOR.message_types_by_name['SignaturePair'] = _SIGNATUREPAIR
DESCRIPTOR.message_types_by_name['SignatureMap'] = _SIGNATUREMAP
DESCRIPTOR.message_types_by_name['FeeComponents'] = _FEECOMPONENTS
DESCRIPTOR.message_types_by_name['TransactionFeeSchedule'] = _TRANSACTIONFEESCHEDULE
DESCRIPTOR.message_types_by_name['FeeData'] = _FEEDATA
DESCRIPTOR.message_types_by_name['FeeSchedule'] = _FEESCHEDULE
DESCRIPTOR.message_types_by_name['CurrentAndNextFeeSchedule'] = _CURRENTANDNEXTFEESCHEDULE
DESCRIPTOR.message_types_by_name['ServiceEndpoint'] = _SERVICEENDPOINT
DESCRIPTOR.message_types_by_name['NodeAddress'] = _NODEADDRESS
DESCRIPTOR.message_types_by_name['NodeAddressBook'] = _NODEADDRESSBOOK
DESCRIPTOR.message_types_by_name['SemanticVersion'] = _SEMANTICVERSION
DESCRIPTOR.message_types_by_name['Setting'] = _SETTING
DESCRIPTOR.message_types_by_name['ServicesConfigurationList'] = _SERVICESCONFIGURATIONLIST
DESCRIPTOR.message_types_by_name['TokenRelationship'] = _TOKENRELATIONSHIP
DESCRIPTOR.message_types_by_name['TokenBalance'] = _TOKENBALANCE
DESCRIPTOR.message_types_by_name['TokenBalances'] = _TOKENBALANCES
DESCRIPTOR.enum_types_by_name['TokenType'] = _TOKENTYPE
DESCRIPTOR.enum_types_by_name['SubType'] = _SUBTYPE
DESCRIPTOR.enum_types_by_name['TokenSupplyType'] = _TOKENSUPPLYTYPE
DESCRIPTOR.enum_types_by_name['TokenFreezeStatus'] = _TOKENFREEZESTATUS
DESCRIPTOR.enum_types_by_name['TokenKycStatus'] = _TOKENKYCSTATUS
DESCRIPTOR.enum_types_by_name['HederaFunctionality'] = _HEDERAFUNCTIONALITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ShardID = _reflection.GeneratedProtocolMessageType('ShardID', (_message.Message,), {
  'DESCRIPTOR' : _SHARDID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ShardID)
  })
_sym_db.RegisterMessage(ShardID)

RealmID = _reflection.GeneratedProtocolMessageType('RealmID', (_message.Message,), {
  'DESCRIPTOR' : _REALMID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.RealmID)
  })
_sym_db.RegisterMessage(RealmID)

AccountID = _reflection.GeneratedProtocolMessageType('AccountID', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.AccountID)
  })
_sym_db.RegisterMessage(AccountID)

FileID = _reflection.GeneratedProtocolMessageType('FileID', (_message.Message,), {
  'DESCRIPTOR' : _FILEID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.FileID)
  })
_sym_db.RegisterMessage(FileID)

ContractID = _reflection.GeneratedProtocolMessageType('ContractID', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ContractID)
  })
_sym_db.RegisterMessage(ContractID)

TransactionID = _reflection.GeneratedProtocolMessageType('TransactionID', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TransactionID)
  })
_sym_db.RegisterMessage(TransactionID)

AccountAmount = _reflection.GeneratedProtocolMessageType('AccountAmount', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTAMOUNT,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.AccountAmount)
  })
_sym_db.RegisterMessage(AccountAmount)

TransferList = _reflection.GeneratedProtocolMessageType('TransferList', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERLIST,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TransferList)
  })
_sym_db.RegisterMessage(TransferList)

NftTransfer = _reflection.GeneratedProtocolMessageType('NftTransfer', (_message.Message,), {
  'DESCRIPTOR' : _NFTTRANSFER,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.NftTransfer)
  })
_sym_db.RegisterMessage(NftTransfer)

TokenTransferList = _reflection.GeneratedProtocolMessageType('TokenTransferList', (_message.Message,), {
  'DESCRIPTOR' : _TOKENTRANSFERLIST,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TokenTransferList)
  })
_sym_db.RegisterMessage(TokenTransferList)

Fraction = _reflection.GeneratedProtocolMessageType('Fraction', (_message.Message,), {
  'DESCRIPTOR' : _FRACTION,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.Fraction)
  })
_sym_db.RegisterMessage(Fraction)

TopicID = _reflection.GeneratedProtocolMessageType('TopicID', (_message.Message,), {
  'DESCRIPTOR' : _TOPICID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TopicID)
  })
_sym_db.RegisterMessage(TopicID)

TokenID = _reflection.GeneratedProtocolMessageType('TokenID', (_message.Message,), {
  'DESCRIPTOR' : _TOKENID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TokenID)
  })
_sym_db.RegisterMessage(TokenID)

ScheduleID = _reflection.GeneratedProtocolMessageType('ScheduleID', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEID,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ScheduleID)
  })
_sym_db.RegisterMessage(ScheduleID)

Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
  'DESCRIPTOR' : _KEY,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.Key)
  })
_sym_db.RegisterMessage(Key)

ThresholdKey = _reflection.GeneratedProtocolMessageType('ThresholdKey', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDKEY,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ThresholdKey)
  })
_sym_db.RegisterMessage(ThresholdKey)

KeyList = _reflection.GeneratedProtocolMessageType('KeyList', (_message.Message,), {
  'DESCRIPTOR' : _KEYLIST,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.KeyList)
  })
_sym_db.RegisterMessage(KeyList)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURE,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.Signature)
  })
_sym_db.RegisterMessage(Signature)

ThresholdSignature = _reflection.GeneratedProtocolMessageType('ThresholdSignature', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDSIGNATURE,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ThresholdSignature)
  })
_sym_db.RegisterMessage(ThresholdSignature)

SignatureList = _reflection.GeneratedProtocolMessageType('SignatureList', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURELIST,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignatureList)
  })
_sym_db.RegisterMessage(SignatureList)

SignaturePair = _reflection.GeneratedProtocolMessageType('SignaturePair', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATUREPAIR,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignaturePair)
  })
_sym_db.RegisterMessage(SignaturePair)

SignatureMap = _reflection.GeneratedProtocolMessageType('SignatureMap', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATUREMAP,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignatureMap)
  })
_sym_db.RegisterMessage(SignatureMap)

FeeComponents = _reflection.GeneratedProtocolMessageType('FeeComponents', (_message.Message,), {
  'DESCRIPTOR' : _FEECOMPONENTS,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.FeeComponents)
  })
_sym_db.RegisterMessage(FeeComponents)

TransactionFeeSchedule = _reflection.GeneratedProtocolMessageType('TransactionFeeSchedule', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONFEESCHEDULE,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TransactionFeeSchedule)
  })
_sym_db.RegisterMessage(TransactionFeeSchedule)

FeeData = _reflection.GeneratedProtocolMessageType('FeeData', (_message.Message,), {
  'DESCRIPTOR' : _FEEDATA,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.FeeData)
  })
_sym_db.RegisterMessage(FeeData)

FeeSchedule = _reflection.GeneratedProtocolMessageType('FeeSchedule', (_message.Message,), {
  'DESCRIPTOR' : _FEESCHEDULE,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.FeeSchedule)
  })
_sym_db.RegisterMessage(FeeSchedule)

CurrentAndNextFeeSchedule = _reflection.GeneratedProtocolMessageType('CurrentAndNextFeeSchedule', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTANDNEXTFEESCHEDULE,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.CurrentAndNextFeeSchedule)
  })
_sym_db.RegisterMessage(CurrentAndNextFeeSchedule)

ServiceEndpoint = _reflection.GeneratedProtocolMessageType('ServiceEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEENDPOINT,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ServiceEndpoint)
  })
_sym_db.RegisterMessage(ServiceEndpoint)

NodeAddress = _reflection.GeneratedProtocolMessageType('NodeAddress', (_message.Message,), {
  'DESCRIPTOR' : _NODEADDRESS,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.NodeAddress)
  })
_sym_db.RegisterMessage(NodeAddress)

NodeAddressBook = _reflection.GeneratedProtocolMessageType('NodeAddressBook', (_message.Message,), {
  'DESCRIPTOR' : _NODEADDRESSBOOK,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.NodeAddressBook)
  })
_sym_db.RegisterMessage(NodeAddressBook)

SemanticVersion = _reflection.GeneratedProtocolMessageType('SemanticVersion', (_message.Message,), {
  'DESCRIPTOR' : _SEMANTICVERSION,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.SemanticVersion)
  })
_sym_db.RegisterMessage(SemanticVersion)

Setting = _reflection.GeneratedProtocolMessageType('Setting', (_message.Message,), {
  'DESCRIPTOR' : _SETTING,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.Setting)
  })
_sym_db.RegisterMessage(Setting)

ServicesConfigurationList = _reflection.GeneratedProtocolMessageType('ServicesConfigurationList', (_message.Message,), {
  'DESCRIPTOR' : _SERVICESCONFIGURATIONLIST,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.ServicesConfigurationList)
  })
_sym_db.RegisterMessage(ServicesConfigurationList)

TokenRelationship = _reflection.GeneratedProtocolMessageType('TokenRelationship', (_message.Message,), {
  'DESCRIPTOR' : _TOKENRELATIONSHIP,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TokenRelationship)
  })
_sym_db.RegisterMessage(TokenRelationship)

TokenBalance = _reflection.GeneratedProtocolMessageType('TokenBalance', (_message.Message,), {
  'DESCRIPTOR' : _TOKENBALANCE,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TokenBalance)
  })
_sym_db.RegisterMessage(TokenBalance)

TokenBalances = _reflection.GeneratedProtocolMessageType('TokenBalances', (_message.Message,), {
  'DESCRIPTOR' : _TOKENBALANCES,
  '__module__' : 'BasicTypes_pb2'
  # @@protoc_insertion_point(class_scope:proto.TokenBalances)
  })
_sym_db.RegisterMessage(TokenBalances)


DESCRIPTOR._options = None
_SIGNATURE._options = None
_THRESHOLDSIGNATURE._options = None
_SIGNATURELIST._options = None
_TRANSACTIONFEESCHEDULE.fields_by_name['feeData']._options = None
_NODEADDRESS.fields_by_name['ipAddress']._options = None
_NODEADDRESS.fields_by_name['portno']._options = None
_NODEADDRESS.fields_by_name['memo']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ConsensusService.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import BasicTypes_pb2 as BasicTypes__pb2
import Timestamp_pb2 as Timestamp__pb2
import ConsensusSubmitMessage_pb2 as ConsensusSubmitMessage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ConsensusService.proto',
  package='com.hedera.mirror.api.proto',
  syntax='proto3',
  serialized_options=b'\n\033com.hedera.mirror.api.protoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x43onsensusService.proto\x12\x1b\x63om.hedera.mirror.api.proto\x1a\x10\x42\x61sicTypes.proto\x1a\x0fTimestamp.proto\x1a\x1c\x43onsensusSubmitMessage.proto\"\x9f\x01\n\x13\x43onsensusTopicQuery\x12\x1f\n\x07topicID\x18\x01 \x01(\x0b\x32\x0e.proto.TopicID\x12,\n\x12\x63onsensusStartTime\x18\x02 \x01(\x0b\x32\x10.proto.Timestamp\x12*\n\x10\x63onsensusEndTime\x18\x03 \x01(\x0b\x32\x10.proto.Timestamp\x12\r\n\x05limit\x18\x04 \x01(\x04\"\xd5\x01\n\x16\x43onsensusTopicResponse\x12,\n\x12\x63onsensusTimestamp\x18\x01 \x01(\x0b\x32\x10.proto.Timestamp\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x12\x13\n\x0brunningHash\x18\x03 \x01(\x0c\x12\x16\n\x0esequenceNumber\x18\x04 \x01(\x04\x12\x1a\n\x12runningHashVersion\x18\x05 \x01(\x04\x12\x33\n\tchunkInfo\x18\x06 \x01(\x0b\x32 .proto.ConsensusMessageChunkInfo2\x8d\x01\n\x10\x43onsensusService\x12y\n\x0esubscribeTopic\x12\x30.com.hedera.mirror.api.proto.ConsensusTopicQuery\x1a\x33.com.hedera.mirror.api.proto.ConsensusTopicResponse0\x01\x42\x1f\n\x1b\x63om.hedera.mirror.api.protoP\x01\x62\x06proto3'
  ,
  dependencies=[BasicTypes__pb2.DESCRIPTOR,Timestamp__pb2.DESCRIPTOR,ConsensusSubmitMessage__pb2.DESCRIPTOR,])




_CONSENSUSTOPICQUERY = _descriptor.Descriptor(
  name='ConsensusTopicQuery',
  full_name='com.hedera.mirror.api.proto.ConsensusTopicQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topicID', full_name='com.hedera.mirror.api.proto.ConsensusTopicQuery.topicID', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensusStartTime', full_name='com.hedera.mirror.api.proto.ConsensusTopicQuery.consensusStartTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensusEndTime', full_name='com.hedera.mirror.api.proto.ConsensusTopicQuery.consensusEndTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='com.hedera.mirror.api.proto.ConsensusTopicQuery.limit', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=280,
)


_CONSENSUSTOPICRESPONSE = _descriptor.Descriptor(
  name='ConsensusTopicResponse',
  full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consensusTimestamp', full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse.consensusTimestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runningHash', full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse.runningHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse.sequenceNumber', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runningHashVersion', full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse.runningHashVersion', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunkInfo', full_name='com.hedera.mirror.api.proto.ConsensusTopicResponse.chunkInfo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=496,
)

_CONSENSUSTOPICQUERY.fields_by_name['topicID'].message_type = BasicTypes__pb2._TOPICID
_CONSENSUSTOPICQUERY.fields_by_name['consensusStartTime'].message_type = Timestamp__pb2._TIMESTAMP
_CONSENSUSTOPICQUERY.fields_by_name['consensusEndTime'].message_type = Timestamp__pb2._TIMESTAMP
_CONSENSUSTOPICRESPONSE.fields_by_name['consensusTimestamp'].message_type = Timestamp__pb2._TIMESTAMP
_CONSENSUSTOPICRESPONSE.fields_by_name['chunkInfo'].message_type = ConsensusSubmitMessage__pb2._CONSENSUSMESSAGECHUNKINFO
DESCRIPTOR.message_types_by_name['ConsensusTopicQuery'] = _CONSENSUSTOPICQUERY
DESCRIPTOR.message_types_by_name['ConsensusTopicResponse'] = _CONSENSUSTOPICRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConsensusTopicQuery = _reflection.GeneratedProtocolMessageType('ConsensusTopicQuery', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSTOPICQUERY,
  '__module__' : 'ConsensusService_pb2'
  # @@protoc_insertion_point(class_scope:com.hedera.mirror.api.proto.ConsensusTopicQuery)
  })
_sym_db.RegisterMessage(ConsensusTopicQuery)

ConsensusTopicResponse = _reflection.GeneratedProtocolMessageType('ConsensusTopicResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSTOPICRESPONSE,
  '__module__' : 'ConsensusService_pb2'
  # @@protoc_insertion_point(class_scope:com.hedera.mirror.api.proto.ConsensusTopicResponse)
  })
_sym_db.RegisterMessage(ConsensusTopicResponse)


DESCRIPTOR._options = None

_CONSENSUSSERVICE = _descriptor.ServiceDescriptor(
  name='ConsensusService',
  full_name='com.hedera.mirror.api.proto.ConsensusService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=499,
  serialized_end=640,
  methods=[
  _descriptor.MethodDescriptor(
    name='subscribeTopic',
    full_name='com.hedera.mirror.api.proto.ConsensusService.subscribeTopic',
    index=0,
    containing_service=None,
    input_type=_CONSENSUSTOPICQUERY,
    output_type=_CONSENSUSTOPICRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONSENSUSSERVICE)

DESCRIPTOR.services_by_name['ConsensusService'] = _CONSENSUSSERVICE

# @@protoc_insertion_point(module_scope)



import os
import setuptools

src_files = os.listdir("src/hcs_grpc_client")
version = "0.16.0"  # keep track of 'hedera-protobufs' version

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="hcs-grpc-client",
    version=version,
    author="Wensheng Wang",
    author_email="wenshengwang@gmail.com",
    description="Hedera HCS gRPC API Python Client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/wensheng/hcs-grpc-api-py-client",
    project_urls={
        "Bug Tracker": "https://github.com/wensheng/hcs-grpc-api-py-client/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    install_requires=['grpcio>=1.38.1',
                      'protobuf>=3.17.3'],
    python_requires=">=3.6",
)



import os
import sys
sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
from ConsensusService_pb2 import (
    ConsensusTopicQuery,
    ConsensusTopicResponse,
    )
from BasicTypes_pb2 import TopicID
from Timestamp_pb2 import Timestamp, TimestampSeconds
from ConsensusService_pb2_grpc import ConsensusServiceStub
